==> ioc-liturgical-react-1.0.3.tgz: package/es/modules/ModalSchemaBasedEditor.js <==
var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import axios from 'axios';
import { Col, ControlLabel, Button, Modal, Row, Well } from 'react-bootstrap';
import Form from "react-jsonschema-form";
import FontAwesome from 'react-fontawesome';
import MessageIcons from '../helpers/MessageIcons';
import DeleteButton from "../helpers/DeleteButton";

/**
 * Display modal content.
 */
export var ModalSchemaBasedEditor = (_temp = _class = function (_React$Component) {
  _inherits(ModalSchemaBasedEditor, _React$Component);

  function ModalSchemaBasedEditor(props) {
    _classCallCheck(this, ModalSchemaBasedEditor);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;

    _this.state = {
      labels: {
        buttons: labels[labelTopics.button],
        messages: labels[labelTopics.messages],
        references: labels[labelTopics.ViewReferences]
      },
      messageIcons: MessageIcons.getMessageIcons(),
      messageIcon: MessageIcons.getMessageIcons().info,
      message: labels[labelTopics.messages].initial,
      resultCount: 0,
      showSearchResults: false,
      schema: {},
      uiSchema: {},
      formData: {},
      data: { values: [{ "id": "", "value:": "" }] },
      showForm: false,
      topicText: "",
      keyText: "",
      httpCodeLabels: labels[labelTopics.httpCodes],
      selectedId: "",
      selectedValue: "",
      selectedSchema: "",
      showModal: true
    };

    _this.close = _this.close.bind(_this);
    _this.open = _this.open.bind(_this);
    _this.fetchData = _this.fetchData.bind(_this);
    _this.setMessage = _this.setMessage.bind(_this);
    _this.getModalFooter = _this.getModalFooter.bind(_this);
    _this.onDelete = _this.onDelete.bind(_this);
    _this.onSubmit = _this.onSubmit.bind(_this);
    return _this;
  }

  ModalSchemaBasedEditor.prototype.setMessage = function setMessage(message) {
    this.setState({
      message: message
    });
  };

  ModalSchemaBasedEditor.prototype.fetchData = function fetchData() {
    var _this2 = this;

    this.setState({
      message: this.state.labels.messages.searching,
      messageIcon: MessageIcons.getMessageIcons().info
    });
    var config = {
      auth: {
        username: this.props.session.userInfo.username,
        password: this.props.session.userInfo.password
      }
    };

    var path = this.props.session.restServer + this.props.restPath + "/" + this.props.idLibrary + "/" + this.props.idTopic + "/" + this.props.idKey;
    axios.get(path, config).then(function (response) {
      if (response.data.valueCount && response.data.valueCount > 0) {
        var data = response.data.values[0];
        var schemaId = data._valueSchemaId;
        var dataSchema = response.data.valueSchemas[schemaId].schema;
        var dataUiSchema = response.data.valueSchemas[schemaId].uiSchema;
        _this2.setState({
          schema: dataSchema,
          uiSchema: dataUiSchema,
          formData: data,
          showForm: true,
          message: _this2.state.labels.messages.found,
          messageIcon: MessageIcons.getMessageIcons().info
        });
      }
    }).catch(function (error) {
      var message = error.message;
      var messageIcon = MessageIcons.getMessageIcons().error;
      if (error && error.response && error.response.status === 404) {
        message = _this2.state.labels.messages.foundNone;
        messageIcon = MessageIcons.getMessageIcons().warning;
        _this2.setState({ data: message, message: message, messageIcon: messageIcon });
      }
    });
  };

  ModalSchemaBasedEditor.prototype.close = function close() {
    this.setState({ showModal: false });
    this.props.onClose(this.state.selectedId, this.state.selectedValue, this.state.selectedSchema, this.state.formData);
  };

  ModalSchemaBasedEditor.prototype.open = function open() {
    this.setState({ showModal: true });
  };

  ModalSchemaBasedEditor.prototype.render = function render() {
    return React.createElement(
      'div',
      null,
      React.createElement(
        Modal,
        {
          backdrop: "static",
          dialogClassName: 'App-Modal-Para-Row-Editor',
          show: this.state.showModal,
          onHide: this.close,
          keyboard: true
        },
        React.createElement(
          Modal.Header,
          { closeButton: true },
          React.createElement(
            Modal.Title,
            null,
            this.props.title
          ),
          this.props.fromText && this.props.fromTitle && React.createElement(
            'div',
            { className: "App-Text-Refers-To" },
            this.props.fromTitle
          ),
          this.props.fromText && this.props.fromId && React.createElement(
            Well,
            { className: "App-Well-From-Text" },
            React.createElement(
              'div',
              { className: "App-Modal-Text" },
              this.props.fromText,
              React.createElement(
                'span',
                { className: "control-label" },
                ' (',
                this.props.fromId,
                ')'
              )
            )
          ),
          this.props.fromText && this.props.toText && this.props.toTitle && React.createElement(
            'div',
            { className: "App-Text-Refers-To" },
            this.props.toTitle
          ),
          this.props.toText && this.props.toId && React.createElement(
            Well,
            { className: "App-Well-To-Text" },
            React.createElement(
              'div',
              { className: "App-Modal-Text" },
              this.props.toText,
              React.createElement(
                'span',
                { className: "control-label" },
                ' (',
                this.props.toId,
                ')'
              )
            )
          ),
          this.props.toText && React.createElement(
            ControlLabel,
            null,
            this.state.labels.references.infoBelow
          ),
          this.props.canUpdate ? React.createElement('div', null) : React.createElement(
            ControlLabel,
            null,
            this.state.labels.messages.readOnly
          )
        ),
        React.createElement(
          Modal.Body,
          null,
          React.createElement(
            Form,
            { schema: this.state.schema,
              uiSchema: this.state.uiSchema,
              formData: this.state.formData,
              onSubmit: this.onSubmit
            },
            React.createElement(
              'div',
              null,
              React.createElement(
                Button,
                {
                  bsStyle: 'primary',
                  type: 'submit',
                  disabled: !this.props.canUpdate
                },
                this.state.labels.buttons.submit
              ),
              React.createElement(
                'span',
                { className: 'App App-message' },
                React.createElement(FontAwesome, {
                  name: this.state.messageIcon }),
                this.state.message
              )
            )
          )
        ),
        React.createElement(
          Modal.Footer,
          null,
          this.getModalFooter()
        )
      )
    );
  };

  return ModalSchemaBasedEditor;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.componentWillMount = function () {
    _this3.setState({
      showModal: _this3.props.showModal
    }, function () {
      this.fetchData();
    });
  };

  this.componentWillReceiveProps = function (nextProps) {
    var labels = nextProps.session.labels;
    var labelTopics = nextProps.session.labelTopics;

    _this3.setState({
      labels: {
        buttons: labels[labelTopics.button],
        messages: labels[labelTopics.messages],
        references: labels[labelTopics.ViewReferences]
      },
      message: labels[labelTopics.messages].initial,
      httpCodeLabels: labels[labelTopics.httpCodes]
    });
  };

  this.onSubmit = function (_ref) {
    var formData = _ref.formData;

    var config = {
      auth: {
        username: _this3.props.session.userInfo.username,
        password: _this3.props.session.userInfo.password
      }
    };
    var path = _this3.props.session.restServer + _this3.props.restPath + "/" + _this3.props.idLibrary + "/" + _this3.props.idTopic + "/" + _this3.props.idKey;
    axios.put(path, formData, config).then(function (response) {
      _this3.setState({
        message: "updated ",
        formData: formData
      });
    }).catch(function (error) {
      var message = error.message;
      var messageIcon = MessageIcons.getMessageIcons().error;
      _this3.setState({ data: message, message: message, messageIcon: messageIcon });
    });
  };

  this.onDelete = function () {
    _this3.close();
  };

  this.getModalFooter = function () {
    if (_this3.state.formData && _this3.state.formData.id) {
      return React.createElement(
        'div',
        null,
        React.createElement(
          Row,
          { className: 'App show-grid App-PDF-Title-Row' },
          React.createElement(
            Col,
            { xs: 3, md: 3 },
            React.createElement(
              Button,
              { className: "App-Modal-Close-Button", onClick: _this3.close },
              _this3.state.labels.buttons.close
            )
          ),
          React.createElement(
            Col,
            { xs: 9, md: 9 },
            React.createElement(DeleteButton, {
              session: _this3.props.session,
              idLibrary: _this3.state.formData.library,
              idTopic: _this3.state.formData.topic,
              idKey: _this3.state.formData.key,
              onDelete: _this3.onDelete
            })
          )
        )
      );
    } else {
      return React.createElement(
        Button,
        { onClick: _this3.close },
        _this3.state.labels.buttons.close
      );
    }
  };
}, _temp);
process.env.NODE_ENV !== "production" ? ModalSchemaBasedEditor.propTypes = {
  session: PropTypes.object.isRequired,
  restPath: PropTypes.string.isRequired,
  onClose: PropTypes.func.isRequired,
  showModal: PropTypes.bool.isRequired,
  title: PropTypes.string.isRequired,
  fromTitle: PropTypes.string,
  fromId: PropTypes.string,
  fromText: PropTypes.string,
  toTitle: PropTypes.string,
  toId: PropTypes.string,
  toText: PropTypes.string,
  idLibrary: PropTypes.string.isRequired,
  idTopic: PropTypes.string.isRequired,
  idKey: PropTypes.string.isRequired,
  canUpdate: PropTypes.bool
} : void 0;
ModalSchemaBasedEditor.defaultProps = {
  canUpdate: true
};

export default ModalSchemaBasedEditor;

==> ioc-liturgical-react-1.0.6.tgz: package/es/modules/ModalSchemaBasedEditor.js <==
var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import axios from 'axios';
import { Col, ControlLabel, Button, Modal, Row, Well } from 'react-bootstrap';
import Form from "react-jsonschema-form";
import FontAwesome from 'react-fontawesome';
import MessageIcons from '../helpers/MessageIcons';
import DeleteButton from "../helpers/DeleteButton";

/**
 * Display modal content.
 */
export var ModalSchemaBasedEditor = (_temp = _class = function (_React$Component) {
  _inherits(ModalSchemaBasedEditor, _React$Component);

  function ModalSchemaBasedEditor(props) {
    _classCallCheck(this, ModalSchemaBasedEditor);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;

    _this.state = {
      labels: {
        buttons: labels[labelTopics.button],
        messages: labels[labelTopics.messages],
        references: labels[labelTopics.ViewReferences]
      },
      messageIcons: MessageIcons.getMessageIcons(),
      messageIcon: MessageIcons.getMessageIcons().info,
      message: labels[labelTopics.messages].initial,
      resultCount: 0,
      showSearchResults: false,
      schema: {},
      uiSchema: {},
      formData: {},
      data: { values: [{ "id": "", "value:": "" }] },
      showForm: false,
      topicText: "",
      keyText: "",
      httpCodeLabels: labels[labelTopics.httpCodes],
      selectedId: "",
      selectedValue: "",
      selectedSchema: "",
      showModal: true
    };

    _this.close = _this.close.bind(_this);
    _this.open = _this.open.bind(_this);
    _this.fetchData = _this.fetchData.bind(_this);
    _this.setMessage = _this.setMessage.bind(_this);
    _this.getModalFooter = _this.getModalFooter.bind(_this);
    _this.onDelete = _this.onDelete.bind(_this);
    _this.onSubmit = _this.onSubmit.bind(_this);
    return _this;
  }

  ModalSchemaBasedEditor.prototype.setMessage = function setMessage(message) {
    this.setState({
      message: message
    });
  };

  ModalSchemaBasedEditor.prototype.fetchData = function fetchData() {
    var _this2 = this;

    this.setState({
      message: this.state.labels.messages.searching,
      messageIcon: MessageIcons.getMessageIcons().info
    });
    var config = {
      auth: {
        username: this.props.session.userInfo.username,
        password: this.props.session.userInfo.password
      }
    };

    var path = this.props.session.restServer + this.props.restPath + "/" + this.props.idLibrary + "/" + this.props.idTopic + "/" + this.props.idKey;
    axios.get(path, config).then(function (response) {
      if (response && response.data && response.data.valueCount && response.data.valueCount > 0) {
        var data = response.data.values[0];
        var schemaId = data._valueSchemaId;
        var dataSchema = response.data.valueSchemas[schemaId].schema;
        var dataUiSchema = response.data.valueSchemas[schemaId].uiSchema;
        _this2.setState({
          schema: dataSchema,
          uiSchema: dataUiSchema,
          formData: data,
          showForm: true,
          message: _this2.state.labels.messages.found,
          messageIcon: MessageIcons.getMessageIcons().info
        });
      }
    }).catch(function (error) {
      if (error) {
        if (error.message) {
          var message = error.message;
          var messageIcon = MessageIcons.getMessageIcons().error;
          if (error && error.response && error.response.status === 404) {
            //                message = this.state.labels.messages.foundNone;
            messageIcon = MessageIcons.getMessageIcons().warning;
            _this2.setState({ data: message, message: message, messageIcon: messageIcon });
          }
        } else {
          alert(JSON.stringify(error));
        }
      }
    });
  };

  ModalSchemaBasedEditor.prototype.close = function close() {
    this.setState({ showModal: false });
    this.props.onClose(this.state.selectedId, this.state.selectedValue, this.state.selectedSchema, this.state.formData);
  };

  ModalSchemaBasedEditor.prototype.open = function open() {
    this.setState({ showModal: true });
  };

  ModalSchemaBasedEditor.prototype.render = function render() {
    return React.createElement(
      'div',
      null,
      React.createElement(
        Modal,
        {
          backdrop: "static",
          dialogClassName: 'App-Modal-Para-Row-Editor',
          show: this.state.showModal,
          onHide: this.close,
          keyboard: true
        },
        React.createElement(
          Modal.Header,
          { closeButton: true },
          React.createElement(
            Modal.Title,
            null,
            this.props.title
          ),
          this.props.fromText && this.props.fromTitle && React.createElement(
            'div',
            { className: "App-Text-Refers-To" },
            this.props.fromTitle
          ),
          this.props.fromText && this.props.fromId && React.createElement(
            Well,
            { className: "App-Well-From-Text" },
            React.createElement(
              'div',
              { className: "App-Modal-Text" },
              this.props.fromText,
              React.createElement(
                'span',
                { className: "control-label" },
                ' (',
                this.props.fromId,
                ')'
              )
            )
          ),
          this.props.fromText && this.props.toText && this.props.toTitle && React.createElement(
            'div',
            { className: "App-Text-Refers-To" },
            this.props.toTitle
          ),
          this.props.toText && this.props.toId && React.createElement(
            Well,
            { className: "App-Well-To-Text" },
            React.createElement(
              'div',
              { className: "App-Modal-Text" },
              this.props.toText,
              React.createElement(
                'span',
                { className: "control-label" },
                ' (',
                this.props.toId,
                ')'
              )
            )
          ),
          this.props.toText && React.createElement(
            ControlLabel,
            null,
            this.state.labels.references.infoBelow
          ),
          this.props.canUpdate ? React.createElement('div', null) : React.createElement(
            ControlLabel,
            null,
            this.state.labels.messages.readOnly
          )
        ),
        React.createElement(
          Modal.Body,
          null,
          React.createElement(
            Form,
            { schema: this.state.schema,
              uiSchema: this.state.uiSchema,
              formData: this.state.formData,
              onSubmit: this.onSubmit
            },
            React.createElement(
              'div',
              null,
              React.createElement(
                Button,
                {
                  bsStyle: 'primary',
                  type: 'submit',
                  disabled: !this.props.canUpdate
                },
                this.state.labels.buttons.submit
              ),
              React.createElement(
                'span',
                { className: 'App App-message' },
                React.createElement(FontAwesome, {
                  name: this.state.messageIcon }),
                this.state.message
              )
            )
          )
        ),
        React.createElement(
          Modal.Footer,
          null,
          this.getModalFooter()
        )
      )
    );
  };

  return ModalSchemaBasedEditor;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.componentWillMount = function () {
    _this3.setState({
      showModal: _this3.props.showModal
    }, function () {
      this.fetchData();
    });
  };

  this.componentWillReceiveProps = function (nextProps) {
    var labels = nextProps.session.labels;
    var labelTopics = nextProps.session.labelTopics;

    _this3.setState({
      labels: {
        buttons: labels[labelTopics.button],
        messages: labels[labelTopics.messages],
        references: labels[labelTopics.ViewReferences]
      },
      message: labels[labelTopics.messages].initial,
      httpCodeLabels: labels[labelTopics.httpCodes]
    });
  };

  this.onSubmit = function (_ref) {
    var formData = _ref.formData;

    var config = {
      auth: {
        username: _this3.props.session.userInfo.username,
        password: _this3.props.session.userInfo.password
      }
    };
    var path = _this3.props.session.restServer + _this3.props.restPath + "/" + _this3.props.idLibrary + "/" + _this3.props.idTopic + "/" + _this3.props.idKey;
    axios.put(path, formData, config).then(function (response) {
      _this3.setState({
        message: "updated ",
        formData: formData
      });
    }).catch(function (error) {
      var message = error.message;
      var messageIcon = MessageIcons.getMessageIcons().error;
      _this3.setState({ data: message, message: message, messageIcon: messageIcon });
    });
  };

  this.onDelete = function () {
    _this3.close();
  };

  this.getModalFooter = function () {
    if (_this3.state.formData && _this3.state.formData.id) {
      return React.createElement(
        'div',
        null,
        React.createElement(
          Row,
          { className: 'App show-grid App-PDF-Title-Row' },
          React.createElement(
            Col,
            { xs: 3, md: 3 },
            React.createElement(
              Button,
              { className: "App-Modal-Close-Button", onClick: _this3.close },
              _this3.state.labels.buttons.close
            )
          ),
          React.createElement(
            Col,
            { xs: 9, md: 9 },
            React.createElement(DeleteButton, {
              session: _this3.props.session,
              idLibrary: _this3.state.formData.library,
              idTopic: _this3.state.formData.topic,
              idKey: _this3.state.formData.key,
              onDelete: _this3.onDelete
            })
          )
        )
      );
    } else {
      return React.createElement(
        Button,
        { onClick: _this3.close },
        _this3.state.labels.buttons.close
      );
    }
  };
}, _temp);
process.env.NODE_ENV !== "production" ? ModalSchemaBasedEditor.propTypes = {
  session: PropTypes.object.isRequired,
  restPath: PropTypes.string.isRequired,
  onClose: PropTypes.func.isRequired,
  showModal: PropTypes.bool.isRequired,
  title: PropTypes.string.isRequired,
  fromTitle: PropTypes.string,
  fromId: PropTypes.string,
  fromText: PropTypes.string,
  toTitle: PropTypes.string,
  toId: PropTypes.string,
  toText: PropTypes.string,
  idLibrary: PropTypes.string.isRequired,
  idTopic: PropTypes.string.isRequired,
  idKey: PropTypes.string.isRequired,
  canUpdate: PropTypes.bool
} : void 0;
ModalSchemaBasedEditor.defaultProps = {
  canUpdate: true
};

export default ModalSchemaBasedEditor;
